//Source file: LocationPriority.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines the priority of a location request.
 *
 */
public final class LocationPriority implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static LocationPriority[] _array = new LocationPriority[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private LocationPriority(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Normal
     */
    public static final int _M_NORMAL =  0;

    /**
     * Normal
     */
    public static final LocationPriority M_NORMAL = new LocationPriority(_M_NORMAL);

    /**
     * High
     */
    public static final int _M_HIGH =  1;

    /**
     * High
     */
    public static final LocationPriority M_HIGH = new LocationPriority(_M_HIGH);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved LocationPriority object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the LocationPriority object
     */
    public String getValueText() {
        switch (_value) {
            case _M_NORMAL:
                return "M_NORMAL";
            case _M_HIGH:
                return "M_HIGH";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LocationPriority getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LocationPriority)) {
            return false;
        }
        LocationPriority locationPriority = (LocationPriority) o; 
        if(!(this.getValue() == locationPriority.getValue())) {
            return false;
        }
        if (this.hashCode() != locationPriority.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LocationPriority

