//Source file: LocationTrigger.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify the criteria for a triggered location report to be generated. The area is defined by an ellipse.
 * 
 */
public final class LocationTrigger implements java.io.Serializable {

    private float longitude;
    private float latitude;
    private float areaSemiMajor;
    private float areaSemiMinor;
    private int angleOfSemiMajor;
    private org.csapi.jr.se.mm.LocationTriggerCriteria criterion;
    private int reportingInterval;

    /**
     * Creates a new LocationTrigger instance.
     */
    public LocationTrigger () {}

    /**
     * Creates a new LocationTrigger instance.
     * @param _longitude   Longitude of the position used in the trigger.
     * @param _latitude   Latitude of the position used in the trigger.
     * @param _areaSemiMajor   Semi major of ellipse area used in the trigger.
     * @param _areaSemiMinor   Semi minor of ellipse area used in the trigger.
     * @param _angleOfSemiMajor   Angle of the semi major of the ellipse area used in the trigger.
     * @param _criterion   Trigger criteria with regard to the ellipse area. 
     * @param _reportingInterval   Duration between generated location reports. 
     */
    public LocationTrigger (float _longitude, float _latitude, float _areaSemiMajor, float _areaSemiMinor, int _angleOfSemiMajor, org.csapi.jr.se.mm.LocationTriggerCriteria _criterion, int _reportingInterval) {

        this.longitude = _longitude;
        this.latitude = _latitude;
        this.areaSemiMajor = _areaSemiMajor;
        this.areaSemiMinor = _areaSemiMinor;
        this.angleOfSemiMajor = _angleOfSemiMajor;
        this.criterion = _criterion;
        this.reportingInterval = _reportingInterval;
    }

    /**
     * This method returns a longitude.
     * 
     * @return a float value
     */
    public float getLongitude() {
        return longitude;
    }

    /**
     * This method returns a latitude.
     * 
     * @return a float value
     */
    public float getLatitude() {
        return latitude;
    }

    /**
     * This method returns a areaSemiMajor.
     * 
     * @return a float value
     */
    public float getAreaSemiMajor() {
        return areaSemiMajor;
    }

    /**
     * This method returns a areaSemiMinor.
     * 
     * @return a float value
     */
    public float getAreaSemiMinor() {
        return areaSemiMinor;
    }

    /**
     * This method returns a angleOfSemiMajor.
     * 
     * @return a int value
     */
    public int getAngleOfSemiMajor() {
        return angleOfSemiMajor;
    }

    /**
     * This method returns a criterion.
     * 
     * @return a org.csapi.jr.se.mm.LocationTriggerCriteria value
     */
    public org.csapi.jr.se.mm.LocationTriggerCriteria getCriterion() {
        return criterion;
    }

    /**
     * This method returns a reportingInterval.
     * 
     * @return a int value
     */
    public int getReportingInterval() {
        return reportingInterval;
    }


    /**
     * This method sets a longitude.
     */ 
    public void setLongitude(float longitude) {
        this.longitude = longitude;
    }

    /**
     * This method sets a latitude.
     */ 
    public void setLatitude(float latitude) {
        this.latitude = latitude;
    }

    /**
     * This method sets a areaSemiMajor.
     */ 
    public void setAreaSemiMajor(float areaSemiMajor) {
        this.areaSemiMajor = areaSemiMajor;
    }

    /**
     * This method sets a areaSemiMinor.
     */ 
    public void setAreaSemiMinor(float areaSemiMinor) {
        this.areaSemiMinor = areaSemiMinor;
    }

    /**
     * This method sets a angleOfSemiMajor.
     */ 
    public void setAngleOfSemiMajor(int angleOfSemiMajor) {
        this.angleOfSemiMajor = angleOfSemiMajor;
    }

    /**
     * This method sets a criterion.
     */ 
    public void setCriterion(org.csapi.jr.se.mm.LocationTriggerCriteria criterion) {
        this.criterion = criterion;
    }

    /**
     * This method sets a reportingInterval.
     */ 
    public void setReportingInterval(int reportingInterval) {
        this.reportingInterval = reportingInterval;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LocationTrigger)) {
            return false;
        } 
        LocationTrigger locationTrigger = (LocationTrigger) o;
        if(!(this.longitude == locationTrigger.longitude)) {
            return false;
        }
        if(!(this.latitude == locationTrigger.latitude)) {
            return false;
        }
        if(!(this.areaSemiMajor == locationTrigger.areaSemiMajor)) {
            return false;
        }
        if(!(this.areaSemiMinor == locationTrigger.areaSemiMinor)) {
            return false;
        }
        if(!(this.angleOfSemiMajor == locationTrigger.angleOfSemiMajor)) {
            return false;
        }
        if ((this.criterion != null) && (locationTrigger.criterion != null)) {
            if(!(this.criterion.equals(locationTrigger.criterion))) {
                return false;
            }
        }
        if(!(this.reportingInterval == locationTrigger.reportingInterval)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LocationTrigger

