//Source file: LocationType.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines the type of location requested.
 *
 */
public final class LocationType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static LocationType[] _array = new LocationType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private LocationType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Current location
     */
    public static final int _M_CURRENT =  0;

    /**
     * Current location
     */
    public static final LocationType M_CURRENT = new LocationType(_M_CURRENT);

    /**
     * Current or last known location
     */
    public static final int _M_CURRENT_OR_LAST_KNOWN =  1;

    /**
     * Current or last known location
     */
    public static final LocationType M_CURRENT_OR_LAST_KNOWN = new LocationType(_M_CURRENT_OR_LAST_KNOWN);

    /**
     * Initial location for an emergency services call
     */
    public static final int _M_INITIAL =  2;

    /**
     * Initial location for an emergency services call
     */
    public static final LocationType M_INITIAL = new LocationType(_M_INITIAL);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved LocationType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the LocationType object
     */
    public String getValueText() {
        switch (_value) {
            case _M_CURRENT:
                return "M_CURRENT";
            case _M_CURRENT_OR_LAST_KNOWN:
                return "M_CURRENT_OR_LAST_KNOWN";
            case _M_INITIAL:
                return "M_INITIAL";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LocationType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LocationType)) {
            return false;
        }
        LocationType locationType = (LocationType) o; 
        if(!(this.getValue() == locationType.getValue())) {
            return false;
        }
        if (this.hashCode() != locationType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LocationType

