//Source file: LocationUncertaintyShape.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines the type of uncertainty shape.
 *
 */
public final class LocationUncertaintyShape implements java.io.Serializable {

    private int _value;
    private static int _size = 7;
    private static LocationUncertaintyShape[] _array = new LocationUncertaintyShape[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private LocationUncertaintyShape(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * No uncertainty shape present.
     */
    public static final int _M_SHAPE_NONE =  0;

    /**
     * No uncertainty shape present.
     */
    public static final LocationUncertaintyShape M_SHAPE_NONE = new LocationUncertaintyShape(_M_SHAPE_NONE);

    /**
     * Uncertainty shape is a circle.
     */
    public static final int _M_SHAPE_CIRCLE =  1;

    /**
     * Uncertainty shape is a circle.
     */
    public static final LocationUncertaintyShape M_SHAPE_CIRCLE = new LocationUncertaintyShape(_M_SHAPE_CIRCLE);

    /**
     * Uncertainty shape is a circle sector.
     */
    public static final int _M_SHAPE_CIRCLE_SECTOR =  2;

    /**
     * Uncertainty shape is a circle sector.
     */
    public static final LocationUncertaintyShape M_SHAPE_CIRCLE_SECTOR = new LocationUncertaintyShape(_M_SHAPE_CIRCLE_SECTOR);

    /**
     * Uncertainty shape is a circle arc stripe.
     */
    public static final int _M_SHAPE_CIRCLE_ARC_STRIPE =  3;

    /**
     * Uncertainty shape is a circle arc stripe.
     */
    public static final LocationUncertaintyShape M_SHAPE_CIRCLE_ARC_STRIPE = new LocationUncertaintyShape(_M_SHAPE_CIRCLE_ARC_STRIPE);

    /**
     * Uncertainty shape is an ellipse.
     */
    public static final int _M_SHAPE_ELLIPSE =  4;

    /**
     * Uncertainty shape is an ellipse.
     */
    public static final LocationUncertaintyShape M_SHAPE_ELLIPSE = new LocationUncertaintyShape(_M_SHAPE_ELLIPSE);

    /**
     * Uncertainty shape is an ellipse sector.
     */
    public static final int _M_SHAPE_ELLIPSE_SECTOR =  5;

    /**
     * Uncertainty shape is an ellipse sector.
     */
    public static final LocationUncertaintyShape M_SHAPE_ELLIPSE_SECTOR = new LocationUncertaintyShape(_M_SHAPE_ELLIPSE_SECTOR);

    /**
     * Uncertainty shape is an ellipse arc stripe.
     */
    public static final int _M_SHAPE_ELLIPSE_ARC_STRIPE =  6;

    /**
     * Uncertainty shape is an ellipse arc stripe.
     */
    public static final LocationUncertaintyShape M_SHAPE_ELLIPSE_ARC_STRIPE = new LocationUncertaintyShape(_M_SHAPE_ELLIPSE_ARC_STRIPE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved LocationUncertaintyShape object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the LocationUncertaintyShape object
     */
    public String getValueText() {
        switch (_value) {
            case _M_SHAPE_NONE:
                return "M_SHAPE_NONE";
            case _M_SHAPE_CIRCLE:
                return "M_SHAPE_CIRCLE";
            case _M_SHAPE_CIRCLE_SECTOR:
                return "M_SHAPE_CIRCLE_SECTOR";
            case _M_SHAPE_CIRCLE_ARC_STRIPE:
                return "M_SHAPE_CIRCLE_ARC_STRIPE";
            case _M_SHAPE_ELLIPSE:
                return "M_SHAPE_ELLIPSE";
            case _M_SHAPE_ELLIPSE_SECTOR:
                return "M_SHAPE_ELLIPSE_SECTOR";
            case _M_SHAPE_ELLIPSE_ARC_STRIPE:
                return "M_SHAPE_ELLIPSE_ARC_STRIPE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 6
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LocationUncertaintyShape getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LocationUncertaintyShape)) {
            return false;
        }
        LocationUncertaintyShape locationUncertaintyShape = (LocationUncertaintyShape) o; 
        if(!(this.getValue() == locationUncertaintyShape.getValue())) {
            return false;
        }
        if (this.hashCode() != locationUncertaintyShape.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LocationUncertaintyShape

