//Source file: NetworkStatusIndicator.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Specifies the country code, mobile network code, access network technology used by the user for the data session and roaming status.
 * 
 */
public final class NetworkStatusIndicator implements java.io.Serializable {

    private String countryCode;
    private String mobileNetworkCode;
    private org.csapi.jr.se.mm.AccessTechnology accessTechnology;
    private org.csapi.jr.se.mm.RoamingStatus roamingStatus;

    /**
     * Creates a new NetworkStatusIndicator instance.
     */
    public NetworkStatusIndicator () {}

    /**
     * Creates a new NetworkStatusIndicator instance.
     * @param _countryCode   Network CC Identification, Country code
     * @param _mobileNetworkCode   Network MNC Identification, Mobile network code
     * @param _accessTechnology   Network access technology used by the user to connect
     * @param _roamingStatus   Roaming Status
     */
    public NetworkStatusIndicator (String _countryCode, String _mobileNetworkCode, org.csapi.jr.se.mm.AccessTechnology _accessTechnology, org.csapi.jr.se.mm.RoamingStatus _roamingStatus) {

        this.countryCode = _countryCode;
        this.mobileNetworkCode = _mobileNetworkCode;
        this.accessTechnology = _accessTechnology;
        this.roamingStatus = _roamingStatus;
    }

    /**
     * This method returns a countryCode.
     * 
     * @return a String value
     */
    public String getCountryCode() {
        return countryCode;
    }

    /**
     * This method returns a mobileNetworkCode.
     * 
     * @return a String value
     */
    public String getMobileNetworkCode() {
        return mobileNetworkCode;
    }

    /**
     * This method returns a accessTechnology.
     * 
     * @return a org.csapi.jr.se.mm.AccessTechnology value
     */
    public org.csapi.jr.se.mm.AccessTechnology getAccessTechnology() {
        return accessTechnology;
    }

    /**
     * This method returns a roamingStatus.
     * 
     * @return a org.csapi.jr.se.mm.RoamingStatus value
     */
    public org.csapi.jr.se.mm.RoamingStatus getRoamingStatus() {
        return roamingStatus;
    }


    /**
     * This method sets a countryCode.
     */ 
    public void setCountryCode(String countryCode) {
        this.countryCode = countryCode;
    }

    /**
     * This method sets a mobileNetworkCode.
     */ 
    public void setMobileNetworkCode(String mobileNetworkCode) {
        this.mobileNetworkCode = mobileNetworkCode;
    }

    /**
     * This method sets a accessTechnology.
     */ 
    public void setAccessTechnology(org.csapi.jr.se.mm.AccessTechnology accessTechnology) {
        this.accessTechnology = accessTechnology;
    }

    /**
     * This method sets a roamingStatus.
     */ 
    public void setRoamingStatus(org.csapi.jr.se.mm.RoamingStatus roamingStatus) {
        this.roamingStatus = roamingStatus;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof NetworkStatusIndicator)) {
            return false;
        } 
        NetworkStatusIndicator networkStatusIndicator = (NetworkStatusIndicator) o;
        if ((this.countryCode != null) && (networkStatusIndicator.countryCode != null)) {
            if(!(this.countryCode.equals(networkStatusIndicator.countryCode)))  {
                return false;
            }
        }
        if ((this.mobileNetworkCode != null) && (networkStatusIndicator.mobileNetworkCode != null)) {
            if(!(this.mobileNetworkCode.equals(networkStatusIndicator.mobileNetworkCode)))  {
                return false;
            }
        }
        if ((this.accessTechnology != null) && (networkStatusIndicator.accessTechnology != null)) {
            if(!(this.accessTechnology.equals(networkStatusIndicator.accessTechnology))) {
                return false;
            }
        }
        if ((this.roamingStatus != null) && (networkStatusIndicator.roamingStatus != null)) {
            if(!(this.roamingStatus.equals(networkStatusIndicator.roamingStatus))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // NetworkStatusIndicator

