//Source file: RoamingStatus.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines the roaming status of the user.
 *
 */
public final class RoamingStatus implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static RoamingStatus[] _array = new RoamingStatus[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private RoamingStatus(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * No information on Roaming status has been found.
     */
    public static final int _UNKNOWN_ROAMING_STATUS =  0;

    /**
     * No information on Roaming status has been found.
     */
    public static final RoamingStatus UNKNOWN_ROAMING_STATUS = new RoamingStatus(_UNKNOWN_ROAMING_STATUS);

    /**
     * User is in the home network
     */
    public static final int _HOME_USER =  1;

    /**
     * User is in the home network
     */
    public static final RoamingStatus HOME_USER = new RoamingStatus(_HOME_USER);

    /**
     * User has roamed to another operator in the same country
     */
    public static final int _NATIONAL_ROAMING =  2;

    /**
     * User has roamed to another operator in the same country
     */
    public static final RoamingStatus NATIONAL_ROAMING = new RoamingStatus(_NATIONAL_ROAMING);

    /**
     * User has roamed to another operator abroad
     */
    public static final int _INTERNATIONAL_ROAMING =  3;

    /**
     * User has roamed to another operator abroad
     */
    public static final RoamingStatus INTERNATIONAL_ROAMING = new RoamingStatus(_INTERNATIONAL_ROAMING);

    /**
     * User has roamed to a partner operator abroad
     */
    public static final int _OPERATOR_ROAMING =  4;

    /**
     * User has roamed to a partner operator abroad
     */
    public static final RoamingStatus OPERATOR_ROAMING = new RoamingStatus(_OPERATOR_ROAMING);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved RoamingStatus object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the RoamingStatus object
     */
    public String getValueText() {
        switch (_value) {
            case _UNKNOWN_ROAMING_STATUS:
                return "UNKNOWN_ROAMING_STATUS";
            case _HOME_USER:
                return "HOME_USER";
            case _NATIONAL_ROAMING:
                return "NATIONAL_ROAMING";
            case _INTERNATIONAL_ROAMING:
                return "INTERNATIONAL_ROAMING";
            case _OPERATOR_ROAMING:
                return "OPERATOR_ROAMING";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static RoamingStatus getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof RoamingStatus)) {
            return false;
        }
        RoamingStatus roamingStatus = (RoamingStatus) o; 
        if(!(this.getValue() == roamingStatus.getValue())) {
            return false;
        }
        if (this.hashCode() != roamingStatus.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // RoamingStatus

