//Source file: TerminalType.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines which kind of terminal is used. 
 *
 */
public final class TerminalType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static TerminalType[] _array = new TerminalType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private TerminalType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Fixed terminal.
     */
    public static final int _M_FIXED =  0;

    /**
     * Fixed terminal.
     */
    public static final TerminalType M_FIXED = new TerminalType(_M_FIXED);

    /**
     * Mobile terminal.
     */
    public static final int _M_MOBILE =  1;

    /**
     * Mobile terminal.
     */
    public static final TerminalType M_MOBILE = new TerminalType(_M_MOBILE);

    /**
     * IP terminal.
     */
    public static final int _M_IP =  2;

    /**
     * IP terminal.
     */
    public static final TerminalType M_IP = new TerminalType(_M_IP);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved TerminalType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the TerminalType object
     */
    public String getValueText() {
        switch (_value) {
            case _M_FIXED:
                return "M_FIXED";
            case _M_MOBILE:
                return "M_MOBILE";
            case _M_IP:
                return "M_IP";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static TerminalType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof TerminalType)) {
            return false;
        }
        TerminalType terminalType = (TerminalType) o; 
        if(!(this.getValue() == terminalType.getValue())) {
            return false;
        }
        if (this.hashCode() != terminalType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // TerminalType

