//Source file: UlExtendedData.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify a location (extended format).
The optional vertical location is defined by the data element Altitude, which contains the altitude in meters above sea level, and the data element AltitudeAccuracy, which contains the accuracy of the altitude.
 * 
 */
public final class UlExtendedData implements java.io.Serializable {

    private org.csapi.jr.se.mm.GeographicalPosition geographicalPosition;
    private org.csapi.jr.se.mm.TerminalType terminalType;
    private boolean altitudePresent;
    private float altitude;
    private float uncertaintyAltitude;
    private boolean timestampPresent;
    private String timestamp;
    private String usedLocationMethod;

    /**
     * Creates a new UlExtendedData instance.
     */
    public UlExtendedData () {}

    /**
     * Creates a new UlExtendedData instance.
     * @param _geographicalPosition   Specification of a position and an area of uncertainty. 
     * @param _terminalType   The kind of terminal used by the user.
     * @param _altitudePresent   Flag indicating if the altitude is present. 
     * @param _altitude   Decimal altitude in meters. 
     * @param _uncertaintyAltitude   Uncertainty of the altitude. 
     * @param _timestampPresent   Flag indicating if the timestamp is present.
     * @param _timestamp   Timestamp indicating when the request was processed.
     * @param _usedLocationMethod   Specifying which location method was used. 
     */
    public UlExtendedData (org.csapi.jr.se.mm.GeographicalPosition _geographicalPosition, org.csapi.jr.se.mm.TerminalType _terminalType, boolean _altitudePresent, float _altitude, float _uncertaintyAltitude, boolean _timestampPresent, String _timestamp, String _usedLocationMethod) {

        this.geographicalPosition = _geographicalPosition;
        this.terminalType = _terminalType;
        this.altitudePresent = _altitudePresent;
        this.altitude = _altitude;
        this.uncertaintyAltitude = _uncertaintyAltitude;
        this.timestampPresent = _timestampPresent;
        this.timestamp = _timestamp;
        this.usedLocationMethod = _usedLocationMethod;
    }

    /**
     * This method returns a geographicalPosition.
     * 
     * @return a org.csapi.jr.se.mm.GeographicalPosition value
     */
    public org.csapi.jr.se.mm.GeographicalPosition getGeographicalPosition() {
        return geographicalPosition;
    }

    /**
     * This method returns a terminalType.
     * 
     * @return a org.csapi.jr.se.mm.TerminalType value
     */
    public org.csapi.jr.se.mm.TerminalType getTerminalType() {
        return terminalType;
    }

    /**
     * This method returns a altitudePresent.
     * 
     * @return a boolean value
     */
    public boolean getAltitudePresent() {
        return altitudePresent;
    }

    /**
     * This method returns a altitude.
     * 
     * @return a float value
     */
    public float getAltitude() {
        return altitude;
    }

    /**
     * This method returns a uncertaintyAltitude.
     * 
     * @return a float value
     */
    public float getUncertaintyAltitude() {
        return uncertaintyAltitude;
    }

    /**
     * This method returns a timestampPresent.
     * 
     * @return a boolean value
     */
    public boolean getTimestampPresent() {
        return timestampPresent;
    }

    /**
     * This method returns a timestamp.
     * 
     * @return a String value
     */
    public String getTimestamp() {
        return timestamp;
    }

    /**
     * This method returns a usedLocationMethod.
     * 
     * @return a String value
     */
    public String getUsedLocationMethod() {
        return usedLocationMethod;
    }


    /**
     * This method sets a geographicalPosition.
     */ 
    public void setGeographicalPosition(org.csapi.jr.se.mm.GeographicalPosition geographicalPosition) {
        this.geographicalPosition = geographicalPosition;
    }

    /**
     * This method sets a terminalType.
     */ 
    public void setTerminalType(org.csapi.jr.se.mm.TerminalType terminalType) {
        this.terminalType = terminalType;
    }

    /**
     * This method sets a altitudePresent.
     */ 
    public void setAltitudePresent(boolean altitudePresent) {
        this.altitudePresent = altitudePresent;
    }

    /**
     * This method sets a altitude.
     */ 
    public void setAltitude(float altitude) {
        this.altitude = altitude;
    }

    /**
     * This method sets a uncertaintyAltitude.
     */ 
    public void setUncertaintyAltitude(float uncertaintyAltitude) {
        this.uncertaintyAltitude = uncertaintyAltitude;
    }

    /**
     * This method sets a timestampPresent.
     */ 
    public void setTimestampPresent(boolean timestampPresent) {
        this.timestampPresent = timestampPresent;
    }

    /**
     * This method sets a timestamp.
     */ 
    public void setTimestamp(String timestamp) {
        this.timestamp = timestamp;
    }

    /**
     * This method sets a usedLocationMethod.
     */ 
    public void setUsedLocationMethod(String usedLocationMethod) {
        this.usedLocationMethod = usedLocationMethod;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UlExtendedData)) {
            return false;
        } 
        UlExtendedData ulExtendedData = (UlExtendedData) o;
        if ((this.geographicalPosition != null) && (ulExtendedData.geographicalPosition != null)) {
            if(!(this.geographicalPosition.equals(ulExtendedData.geographicalPosition))) {
                return false;
            }
        }
        if ((this.terminalType != null) && (ulExtendedData.terminalType != null)) {
            if(!(this.terminalType.equals(ulExtendedData.terminalType))) {
                return false;
            }
        }
        if(!(this.altitudePresent == ulExtendedData.altitudePresent)) {
            return false;
        }
        if(!(this.altitude == ulExtendedData.altitude)) {
            return false;
        }
        if(!(this.uncertaintyAltitude == ulExtendedData.uncertaintyAltitude)) {
            return false;
        }
        if(!(this.timestampPresent == ulExtendedData.timestampPresent)) {
            return false;
        }
        if(!(this.timestamp == ulExtendedData.timestamp))  {
            return false;
        }
        if ((this.usedLocationMethod != null) && (ulExtendedData.usedLocationMethod != null)) {
            if(!(this.usedLocationMethod.equals(ulExtendedData.usedLocationMethod)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UlExtendedData

