//Source file: UserInfo.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Used to reference the user name and password supplied by the user, if known by the network
 * 
 */
public final class UserInfo implements java.io.Serializable {

    private String userName;
    private String password;

    /**
     * Creates a new UserInfo instance.
     */
    public UserInfo () {}

    /**
     * Creates a new UserInfo instance.
     * @param _userName   User name as provided in a PPP/CHAP message.
     * @param _password   Password as provided in a PPP/CHAP message.
     */
    public UserInfo (String _userName, String _password) {

        this.userName = _userName;
        this.password = _password;
    }

    /**
     * This method returns a userName.
     * 
     * @return a String value
     */
    public String getUserName() {
        return userName;
    }

    /**
     * This method returns a password.
     * 
     * @return a String value
     */
    public String getPassword() {
        return password;
    }


    /**
     * This method sets a userName.
     */ 
    public void setUserName(String userName) {
        this.userName = userName;
    }

    /**
     * This method sets a password.
     */ 
    public void setPassword(String password) {
        this.password = password;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UserInfo)) {
            return false;
        } 
        UserInfo userInfo = (UserInfo) o;
        if ((this.userName != null) && (userInfo.userName != null)) {
            if(!(this.userName.equals(userInfo.userName)))  {
                return false;
            }
        }
        if ((this.password != null) && (userInfo.password != null)) {
            if(!(this.password.equals(userInfo.password)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UserInfo

