//Source file: UserLocation.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify the identity and location of a user (basic format). 
 * 
 */
public final class UserLocation implements java.io.Serializable {

    private org.csapi.jr.se.Address userID;
    private org.csapi.jr.se.mm.MobilityError statusCode;
    private org.csapi.jr.se.mm.GeographicalPosition geographicalPosition;

    /**
     * Creates a new UserLocation instance.
     */
    public UserLocation () {}

    /**
     * Creates a new UserLocation instance.
     * @param _userID   The address of the user.
     * @param _statusCode   Indicator of error.
     * @param _geographicalPosition   Specification of a position and an area of uncertainty. If StatusCode is indicating an error, this value is undefined.
     */
    public UserLocation (org.csapi.jr.se.Address _userID, org.csapi.jr.se.mm.MobilityError _statusCode, org.csapi.jr.se.mm.GeographicalPosition _geographicalPosition) {

        this.userID = _userID;
        this.statusCode = _statusCode;
        this.geographicalPosition = _geographicalPosition;
    }

    /**
     * This method returns a userID.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getUserID() {
        return userID;
    }

    /**
     * This method returns a statusCode.
     * 
     * @return a org.csapi.jr.se.mm.MobilityError value
     */
    public org.csapi.jr.se.mm.MobilityError getStatusCode() {
        return statusCode;
    }

    /**
     * This method returns a geographicalPosition.
     * 
     * @return a org.csapi.jr.se.mm.GeographicalPosition value
     */
    public org.csapi.jr.se.mm.GeographicalPosition getGeographicalPosition() {
        return geographicalPosition;
    }


    /**
     * This method sets a userID.
     */ 
    public void setUserID(org.csapi.jr.se.Address userID) {
        this.userID = userID;
    }

    /**
     * This method sets a statusCode.
     */ 
    public void setStatusCode(org.csapi.jr.se.mm.MobilityError statusCode) {
        this.statusCode = statusCode;
    }

    /**
     * This method sets a geographicalPosition.
     */ 
    public void setGeographicalPosition(org.csapi.jr.se.mm.GeographicalPosition geographicalPosition) {
        this.geographicalPosition = geographicalPosition;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UserLocation)) {
            return false;
        } 
        UserLocation userLocation = (UserLocation) o;
        if ((this.userID != null) && (userLocation.userID != null)) {
            if(!(this.userID.equals(userLocation.userID))) {
                return false;
            }
        }
        if ((this.statusCode != null) && (userLocation.statusCode != null)) {
            if(!(this.statusCode.equals(userLocation.statusCode))) {
                return false;
            }
        }
        if ((this.geographicalPosition != null) && (userLocation.geographicalPosition != null)) {
            if(!(this.geographicalPosition.equals(userLocation.geographicalPosition))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UserLocation

