//Source file: UserLocationEmergencyTrigger.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines which event triggered the emergency User Location report. 
 *
 */
public final class UserLocationEmergencyTrigger implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static UserLocationEmergencyTrigger[] _array = new UserLocationEmergencyTrigger[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UserLocationEmergencyTrigger(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * An emergency service user originated an emergency call.
     */
    public static final int _ULE_CALL_ORIGINATION =  0;

    /**
     * An emergency service user originated an emergency call.
     */
    public static final UserLocationEmergencyTrigger ULE_CALL_ORIGINATION = new UserLocationEmergencyTrigger(_ULE_CALL_ORIGINATION);

    /**
     * An emergency service user released an emergency call.
     */
    public static final int _ULE_CALL_RELEASE =  1;

    /**
     * An emergency service user released an emergency call.
     */
    public static final UserLocationEmergencyTrigger ULE_CALL_RELEASE = new UserLocationEmergencyTrigger(_ULE_CALL_RELEASE);

    /**
     * The report is a response to an emergency location report request.
     */
    public static final int _ULE_LOCATION_REQUEST =  2;

    /**
     * The report is a response to an emergency location report request.
     */
    public static final UserLocationEmergencyTrigger ULE_LOCATION_REQUEST = new UserLocationEmergencyTrigger(_ULE_LOCATION_REQUEST);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UserLocationEmergencyTrigger object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UserLocationEmergencyTrigger object
     */
    public String getValueText() {
        switch (_value) {
            case _ULE_CALL_ORIGINATION:
                return "ULE_CALL_ORIGINATION";
            case _ULE_CALL_RELEASE:
                return "ULE_CALL_RELEASE";
            case _ULE_LOCATION_REQUEST:
                return "ULE_LOCATION_REQUEST";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UserLocationEmergencyTrigger getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UserLocationEmergencyTrigger)) {
            return false;
        }
        UserLocationEmergencyTrigger userLocationEmergencyTrigger = (UserLocationEmergencyTrigger) o; 
        if(!(this.getValue() == userLocationEmergencyTrigger.getValue())) {
            return false;
        }
        if (this.hashCode() != userLocationEmergencyTrigger.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UserLocationEmergencyTrigger

