//Source file: UserStatusExtended.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines the Sequence of Data Elements that specify the identity and status of a user.
 * 
 */
public final class UserStatusExtended implements java.io.Serializable {

    private String userID;
    private org.csapi.jr.se.mm.MobilityError statusCode;
    private org.csapi.jr.se.mm.UserStatusIndicatorExtended status;
    private org.csapi.jr.se.mm.TerminalType terminalType;
    private org.csapi.jr.se.mm.AuthStatusIndicator authenticationStatus;
    private org.csapi.jr.se.mm.NetworkStatusIndicator networkStatus;
    private String userIPAddress;
    private String userMSISDN;
    private org.csapi.jr.se.mm.UserInfo userInfo;
    private String userConnectionID;
    private String accessPointName;

    /**
     * Creates a new UserStatusExtended instance.
     */
    public UserStatusExtended () {}

    /**
     * Creates a new UserStatusExtended instance.
     * @param _userID   The user address.
     * @param _statusCode   Indicator of error.
     * @param _status   The current status of the user. 
     * @param _terminalType   The kind of terminal used by the user.
     * @param _authenticationStatus   The current authentication status of the user
     * @param _networkStatus   Country code, Mobile network code, technology and Roaming status
     * @param _userIPAddress   The allocated IP address for the user.
If there is no IPAddress allocated then this is represented with the empty string.
     * @param _userMSISDN   The user MSISDN. If the MSISDN address is not known, then this is represented with the empty string.
     * @param _userInfo   Used to reference the user name and password supplied by the user during user-network authentication, if known by the network.
     * @param _userConnectionID   Combination of User IP Address and TCP port. This combination uniquely identifies the user's TCP connection, because one user can have several TCP connections ongoing at the same time. The User IP Address contained in UserConnectionID can be the same as the userIPAddress, but this is not always the case since a router in the data network might have translated the UserIPAddress to another IP-address. The latter is then contained in UserConnectionID.
     * @param _accessPointName   Provides the Access Point Name of the Internet Service Provider
     */
    public UserStatusExtended (String _userID, org.csapi.jr.se.mm.MobilityError _statusCode, org.csapi.jr.se.mm.UserStatusIndicatorExtended _status, org.csapi.jr.se.mm.TerminalType _terminalType, org.csapi.jr.se.mm.AuthStatusIndicator _authenticationStatus, org.csapi.jr.se.mm.NetworkStatusIndicator _networkStatus, String _userIPAddress, String _userMSISDN, org.csapi.jr.se.mm.UserInfo _userInfo, String _userConnectionID, String _accessPointName) {

        this.userID = _userID;
        this.statusCode = _statusCode;
        this.status = _status;
        this.terminalType = _terminalType;
        this.authenticationStatus = _authenticationStatus;
        this.networkStatus = _networkStatus;
        this.userIPAddress = _userIPAddress;
        this.userMSISDN = _userMSISDN;
        this.userInfo = _userInfo;
        this.userConnectionID = _userConnectionID;
        this.accessPointName = _accessPointName;
    }

    /**
     * This method returns a userID.
     * 
     * @return a String value
     */
    public String getUserID() {
        return userID;
    }

    /**
     * This method returns a statusCode.
     * 
     * @return a org.csapi.jr.se.mm.MobilityError value
     */
    public org.csapi.jr.se.mm.MobilityError getStatusCode() {
        return statusCode;
    }

    /**
     * This method returns a status.
     * 
     * @return a org.csapi.jr.se.mm.UserStatusIndicatorExtended value
     */
    public org.csapi.jr.se.mm.UserStatusIndicatorExtended getStatus() {
        return status;
    }

    /**
     * This method returns a terminalType.
     * 
     * @return a org.csapi.jr.se.mm.TerminalType value
     */
    public org.csapi.jr.se.mm.TerminalType getTerminalType() {
        return terminalType;
    }

    /**
     * This method returns a authenticationStatus.
     * 
     * @return a org.csapi.jr.se.mm.AuthStatusIndicator value
     */
    public org.csapi.jr.se.mm.AuthStatusIndicator getAuthenticationStatus() {
        return authenticationStatus;
    }

    /**
     * This method returns a networkStatus.
     * 
     * @return a org.csapi.jr.se.mm.NetworkStatusIndicator value
     */
    public org.csapi.jr.se.mm.NetworkStatusIndicator getNetworkStatus() {
        return networkStatus;
    }

    /**
     * This method returns a userIPAddress.
     * 
     * @return a String value
     */
    public String getUserIPAddress() {
        return userIPAddress;
    }

    /**
     * This method returns a userMSISDN.
     * 
     * @return a String value
     */
    public String getUserMSISDN() {
        return userMSISDN;
    }

    /**
     * This method returns a userInfo.
     * 
     * @return a org.csapi.jr.se.mm.UserInfo value
     */
    public org.csapi.jr.se.mm.UserInfo getUserInfo() {
        return userInfo;
    }

    /**
     * This method returns a userConnectionID.
     * 
     * @return a String value
     */
    public String getUserConnectionID() {
        return userConnectionID;
    }

    /**
     * This method returns a accessPointName.
     * 
     * @return a String value
     */
    public String getAccessPointName() {
        return accessPointName;
    }


    /**
     * This method sets a userID.
     */ 
    public void setUserID(String userID) {
        this.userID = userID;
    }

    /**
     * This method sets a statusCode.
     */ 
    public void setStatusCode(org.csapi.jr.se.mm.MobilityError statusCode) {
        this.statusCode = statusCode;
    }

    /**
     * This method sets a status.
     */ 
    public void setStatus(org.csapi.jr.se.mm.UserStatusIndicatorExtended status) {
        this.status = status;
    }

    /**
     * This method sets a terminalType.
     */ 
    public void setTerminalType(org.csapi.jr.se.mm.TerminalType terminalType) {
        this.terminalType = terminalType;
    }

    /**
     * This method sets a authenticationStatus.
     */ 
    public void setAuthenticationStatus(org.csapi.jr.se.mm.AuthStatusIndicator authenticationStatus) {
        this.authenticationStatus = authenticationStatus;
    }

    /**
     * This method sets a networkStatus.
     */ 
    public void setNetworkStatus(org.csapi.jr.se.mm.NetworkStatusIndicator networkStatus) {
        this.networkStatus = networkStatus;
    }

    /**
     * This method sets a userIPAddress.
     */ 
    public void setUserIPAddress(String userIPAddress) {
        this.userIPAddress = userIPAddress;
    }

    /**
     * This method sets a userMSISDN.
     */ 
    public void setUserMSISDN(String userMSISDN) {
        this.userMSISDN = userMSISDN;
    }

    /**
     * This method sets a userInfo.
     */ 
    public void setUserInfo(org.csapi.jr.se.mm.UserInfo userInfo) {
        this.userInfo = userInfo;
    }

    /**
     * This method sets a userConnectionID.
     */ 
    public void setUserConnectionID(String userConnectionID) {
        this.userConnectionID = userConnectionID;
    }

    /**
     * This method sets a accessPointName.
     */ 
    public void setAccessPointName(String accessPointName) {
        this.accessPointName = accessPointName;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UserStatusExtended)) {
            return false;
        } 
        UserStatusExtended userStatusExtended = (UserStatusExtended) o;
        if ((this.userID != null) && (userStatusExtended.userID != null)) {
            if(!(this.userID.equals(userStatusExtended.userID)))  {
                return false;
            }
        }
        if ((this.statusCode != null) && (userStatusExtended.statusCode != null)) {
            if(!(this.statusCode.equals(userStatusExtended.statusCode))) {
                return false;
            }
        }
        if ((this.status != null) && (userStatusExtended.status != null)) {
            if(!(this.status.equals(userStatusExtended.status))) {
                return false;
            }
        }
        if ((this.terminalType != null) && (userStatusExtended.terminalType != null)) {
            if(!(this.terminalType.equals(userStatusExtended.terminalType))) {
                return false;
            }
        }
        if ((this.authenticationStatus != null) && (userStatusExtended.authenticationStatus != null)) {
            if(!(this.authenticationStatus.equals(userStatusExtended.authenticationStatus))) {
                return false;
            }
        }
        if ((this.networkStatus != null) && (userStatusExtended.networkStatus != null)) {
            if(!(this.networkStatus.equals(userStatusExtended.networkStatus))) {
                return false;
            }
        }
        if ((this.userIPAddress != null) && (userStatusExtended.userIPAddress != null)) {
            if(!(this.userIPAddress.equals(userStatusExtended.userIPAddress)))  {
                return false;
            }
        }
        if ((this.userMSISDN != null) && (userStatusExtended.userMSISDN != null)) {
            if(!(this.userMSISDN.equals(userStatusExtended.userMSISDN)))  {
                return false;
            }
        }
        if ((this.userInfo != null) && (userStatusExtended.userInfo != null)) {
            if(!(this.userInfo.equals(userStatusExtended.userInfo))) {
                return false;
            }
        }
        if ((this.userConnectionID != null) && (userStatusExtended.userConnectionID != null)) {
            if(!(this.userConnectionID.equals(userStatusExtended.userConnectionID)))  {
                return false;
            }
        }
        if ((this.accessPointName != null) && (userStatusExtended.accessPointName != null)) {
            if(!(this.accessPointName.equals(userStatusExtended.accessPointName)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UserStatusExtended

