//Source file: UserStatusIndicator.java
//Date: June 2006
//Mobility Interfaces and Data Types for 3GPP TS 29.198-06 V6.6.0, Release 6

package org.csapi.jr.se.mm;

/**
 * Defines the status of a user.
NOTE:	P_US_BUSY is only applicable to mobile (Camel) telephony users.
 *
 */
public final class UserStatusIndicator implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static UserStatusIndicator[] _array = new UserStatusIndicator[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UserStatusIndicator(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * User is reachable
     */
    public static final int _US_REACHABLE =  0;

    /**
     * User is reachable
     */
    public static final UserStatusIndicator US_REACHABLE = new UserStatusIndicator(_US_REACHABLE);

    /**
     * User is not reachable
     */
    public static final int _US_NOT_REACHABLE =  1;

    /**
     * User is not reachable
     */
    public static final UserStatusIndicator US_NOT_REACHABLE = new UserStatusIndicator(_US_NOT_REACHABLE);

    /**
     * User is busy (only applicable for interactive user status request, not when triggers are used)
     */
    public static final int _US_BUSY =  2;

    /**
     * User is busy (only applicable for interactive user status request, not when triggers are used)
     */
    public static final UserStatusIndicator US_BUSY = new UserStatusIndicator(_US_BUSY);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UserStatusIndicator object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UserStatusIndicator object
     */
    public String getValueText() {
        switch (_value) {
            case _US_REACHABLE:
                return "US_REACHABLE";
            case _US_NOT_REACHABLE:
                return "US_NOT_REACHABLE";
            case _US_BUSY:
                return "US_BUSY";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UserStatusIndicator getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UserStatusIndicator)) {
            return false;
        }
        UserStatusIndicator userStatusIndicator = (UserStatusIndicator) o; 
        if(!(this.getValue() == userStatusIndicator.getValue())) {
            return false;
        }
        if (this.hashCode() != userStatusIndicator.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UserStatusIndicator

